@@ -2,7 +2,9 @@ import airflow.utils.operator_helpers
 
 from dbnd._core.current import try_get_current_task_run
 from dbnd._core.utils.uid_utils import get_airflow_instance_uid
-from dbnd_airflow.tracking.dbnd_airflow_conf import extend_airflow_ctx_with_dbnd_tracking_info
+from dbnd_airflow.tracking.dbnd_airflow_conf import (
+    extend_airflow_ctx_with_dbnd_tracking_info
+)
 
 
 def context_to_airflow_vars(context, in_env_var_format=False):
